pub struct Column { /* private fields */ }Implementations
Sourceimpl Column
impl Column
pub fn new(name: &'static str, col_type: &'static str) -> Self
Sourcepub fn indexed(self) -> Self
pub fn indexed(self) -> Self
Marks this column as filterable.
Filterable columns are indexed on the document table and stored as sqlite-vec metadata columns so supported filters can be applied during KNN candidate search. Filters on other document-table fields are applied after candidate search with an exhaustive candidate limit, which is correct but can be more expensive on large stores.